
## pqnha_cozinha

---
py_cozinha é parte de um sistema que etou desenvolvendo para auxiliar tarefas administrativas e a logística 
de funcionamento de restaurantes e lanchonetes.
O sistema se divide em três partes:
O nome que dei ao sistema como um todo é paçoquinha.

---
  - Pedidos, atendimento.
  - Cozinha, bar.
  - Adminisreação/caixa.

---
## Essa parte do sistema tem a finalidade de enviar os pedidos a cozinha.

  O sistema tem por objetivo o uso de software livre e sistemas linux.
  Também temos a intenção de construir integração com a plataforma android.
  * Este software tem dentre outras a finalidade educacional.
  * Academia do Software livre (São Lourenço - Minas Gerais).

---
Visite  <http://www.asl-sl.com.br>
Colaboradores:
Leonardo de Araújo Lima
<leonardo@asl-sl.com.br>
